{"changed":true,"filter":false,"title":"Template.test.js","tooltip":"/test/Template.test.js","value":"/*global expect*/\n\n/**\n * Dependencies.\n */\n\nvar $ = require('jquery')\nvar Template = require('../src/Template')\nvar fs = require('fs')\nvar utils = require('../src/utils')\n\n/**\n * Template methods.\n */\n\ndescribe('The method', function () {\n\n  describe('Template#compile', function () {\n\n    beforeEach(function () {\n      this.template = new Template()\n    })\n\n    it('should return 4', function () {\n      var result = this.template.compile('2 + 2')\n      expect(result).toEqual(4)\n    })\n\n    it('should return 10', function () {\n      var result = this.template.compile('((10 / 2) * 3) - 5')\n      expect(result).toEqual(10)\n    })\n\n    it('should concatenate strings', function () {\n      var result = this.template.compile('\"Hello, \" + \"World!\"')\n      expect(result).toEqual('Hello, World!')\n    })\n\n    it('should replace the `name` variable', function () {\n      this.template.vars = {\n        name: 'Guilherme'\n      }\n\n      var result = this.template.compile('\"Your name is \" + name')\n      expect(result).toEqual('Your name is Guilherme')\n    })\n\n    it('should solve operations and concatenations', function () {\n      this.template.vars = {\n        name: 'Guilherme',\n        lastname: 'Santiago',\n        age: 20\n      }\n\n      var result = this.template.compile('name + \" \" + lastname + \" is \" + (age + 1) + \" years old\"')\n      var expected = 'Guilherme Santiago is 21 years old'\n      expect(result).toEqual(expected)\n    })\n\n    it('should return an array', function () {\n      var expected = ['html', 'js', ['css', ['stylus', 'sass', 'less']]]\n      var result = this.template.compile('[\"html\", \"js\", [\"css\", [\"stylus\", \"sass\", \"less\"]]]')\n      expect(result).toEqual(expected)\n    })\n\n    it('should return an object', function () {\n      var expected = {\n        name: 'object',\n        size: {width: 20, height: 30}\n      }\n\n      var result = this.template.compile('{name: \"object\", size: {width: 20, height: 30}}')\n      expect(result).toEqual(expected)\n    })\n\n    it('should suppor contexts for `this` keyword', function (done) {\n      this.template.context = {\n        myFunc: function () {\n          done()\n          return 0\n        },\n        a: 10\n      }\n\n      this.template.vars = {\n        b: 5\n      }\n\n      var result = this.template.compile('this.myFunc() + this.a  + b')\n      expect(result).toEqual(15)\n    })\n\n  })\n\n\n  describe('Template#supplant', function () {\n\n    beforeEach(function () {\n      this.template = new Template()\n    })\n\n    it('should return 8', function () {\n      var result = this.template.supplant('Your result is {{4 * 2}}')\n      expect(result).toEqual('Your result is 8')\n    })\n\n    it('should return full name', function () {\n      this.template.vars = {\n        name: 'Guilherme',\n        lastname: 'Santiago'\n      }\n\n      var result = this.template.supplant('Your full name is {{name}} {{lastname}}!')\n      expect(result).toEqual('Your full name is Guilherme Santiago!')\n    })\n\n    it('should escape strings by default', function () {\n      this.template.vars.str = 'You & I aren\\'t <\"GREAT\">'\n      var expected = 'You &amp; I aren&#x27;t &lt;&quot;GREAT&quot;&gt;'\n      var result = this.template.supplant('{{str}}')\n      expect(result).toEqual(expected)\n    })\n\n    it('should return unescaped strings when `{% %}` delimiters are used', function () {\n      var expected = this.template.vars.str = 'You & I aren\\'t <\"GREAT\">'\n      var result = this.template.supplant('{% str %}')\n      expect(result).toEqual(expected)\n    })\n\n    it('should call a function', function (done) {\n      this.template.vars = {\n        myFunc: function () {\n          done()\n        }\n      }\n\n      this.template.supplant('{{ myFunc() }}')\n    })\n\n    it('should return an object formated in JSON', function () {\n      var pete = {\n        name: 'Peter',\n        lastName: 'Parker',\n        items: ['a', 'b', 'c']\n      }\n\n      this.template.vars = {\n        myObject: pete\n      }\n\n      var result = this.template.supplant('{{myObject}}')\n\n      expect(result).toEqual(utils.escape(JSON.stringify(pete, null, 2)))\n    })\n\n    it('should return a function in string format', function () {\n      var myFunc = function (arg1, arg2) {\n        return arg1 + arg2\n      }\n\n      this.template.vars = {myFunc: myFunc}\n\n      var result = this.template.supplant('{{myFunc}}')\n\n      expect(result).toEqual(utils.escape(myFunc.toString()))\n    })\n  })\n\n\n  describe('Template#parse', function () {\n\n    it('should render <div>', function () {\n      var template = new Template('<div>{{ name }} {% lastname %}</div>')\n      var result = template.parse({name: 'Guilherme', lastname: 'Santiago'})\n      expect(result).toEqual('<div>Guilherme Santiago</div>')\n    })\n\n    it('should render a simple node text', function () {\n      var template = new Template('This is my {{ str }}!!!')\n      var result = template.parse({str: 'text'})\n      expect(result).toEqual('This is my text!!!')\n    })\n\n    it('should render multiple elements', function () {\n      var source = fs.readFileSync(__dirname + '/fixtures/templates/multiple-elements.html', 'utf8')\n      var expected = fs.readFileSync(__dirname + '/fixtures/templates/multiple-elements.expected.html', 'utf8')\n      var template = new Template(source)\n\n      var result = template.parse({\n        firstname: 'Guilherme',\n        description: '<strong>Front-end Developer</strong>',\n        user: {\n          name: 'Guilherme Santiago',\n          email: 'guilherme@email.com'\n        }\n      })\n\n      expect(result).toEqual(expected.trim())\n    })\n\n  })\n\n\n  describe('Template#addDirective', function () {\n\n    it('should add a new directive', function () {\n      Template.addDirective('uppercase', function ($el, value, props) {\n        if (this.compile(value)) {\n          $el.text($el.text().toUpperCase())\n        }\n      })\n\n      var template = new Template('<div :uppercase=\"true\">hello</div>')\n      var expected = '<div>HELLO</div>'\n      var result = template.parse()\n\n      expect(result).toEqual(expected)\n    })\n\n  })\n\n  describe('Template#setSource', function () {\n\n    it('should set the template source', function () {\n      var template = new Template('{{ 1 + 2 }}')\n      expect(template.parse()).toEqual('3')\n      template.setSource('{{ 5 * 5 }}')\n      expect(template.parse()).toEqual('25')\n    })\n\n  })\n\n})\n\n\n/**\n * Directives\n */\n\ndescribe('The directive', function () {\n\n  describe(':bind', function () {\n    it('should replace the element\\'s text', function () {\n      var template = new Template('<span :bind=\"name\">Your name</span>')\n      var result = template.parse({name: 'Guilhermão'})\n      expect(result).toEqual('<span>Guilhermão</span>')\n    })\n  })\n\n  describe(':show', function () {\n    it('should show the element if expression given is truthy', function () {\n      var source = fs.readFileSync(__dirname + '/fixtures/templates/directive-show.html', 'utf8')\n      var expected1 = fs.readFileSync(__dirname + '/fixtures/templates/directive-show.expected1.html', 'utf8')\n      var expected2 = fs.readFileSync(__dirname + '/fixtures/templates/directive-show.expected2.html', 'utf8')\n\n      var template = new Template(source)\n      var result1 = template.parse({user: {name: 'Guilherme Santiago', email: 'guilherme@email.com'}})\n      var result2 = template.parse({user: {name: 'Zilla Zillão'}})\n\n      expect(result1).toEqual(expected1.trim())\n      expect(result2).toEqual(expected2.trim())\n    })\n  })\n\n  describe(':hide', function () {\n    it('should remove the element if the expression given is false', function () {\n      var source = fs.readFileSync(__dirname + '/fixtures/templates/directive-hide.html', 'utf8')\n      var expected1 = fs.readFileSync(__dirname + '/fixtures/templates/directive-hide.expected1.html', 'utf8')\n      var expected2 = fs.readFileSync(__dirname + '/fixtures/templates/directive-hide.expected2.html', 'utf8')\n\n      var template = new Template(source)\n      var result1 = template.parse({user: {name: 'Guilherme Santiago', email: 'guilherme@email.com'}})\n      var result2 = template.parse({user: {name: 'Zilla Zillão'}})\n\n      expect(result1).toEqual(expected1.trim())\n      expect(result2).toEqual(expected2.trim())\n    })\n  })\n\n  describe(':class', function () {\n    it('should apply classes to element', function () {\n      var source = fs.readFileSync(__dirname + '/fixtures/templates/directive-class.html', 'utf8')\n      var expected1 = fs.readFileSync(__dirname + '/fixtures/templates/directive-class.expected1.html', 'utf8')\n      var expected2 = fs.readFileSync(__dirname + '/fixtures/templates/directive-class.expected2.html', 'utf8')\n\n      var template = new Template(source)\n      var result1 = template.parse({hasContainer: true, color: 'white', fontSize: 16})\n      var result2 = template.parse({hasContainer: true, color: 'black', fontSize: 18})\n\n      expect($(result1)[0]).toEqual($(expected1.trim())[0])\n      expect($(result2)[0]).toEqual($(expected2.trim())[0])\n    })\n  })\n\n  describe(':selected', function () {\n    it('sould set `selected` attribute if the expression given is truthy', function () {\n      var source = fs.readFileSync(__dirname + '/fixtures/templates/directive-selected.html', 'utf8')\n      var expected1 = fs.readFileSync(__dirname + '/fixtures/templates/directive-selected.expected1.html', 'utf8')\n      var expected2 = fs.readFileSync(__dirname + '/fixtures/templates/directive-selected.expected2.html', 'utf8')\n\n      var template = new Template(source)\n      var result1 = $(template.parse({option: 1}))[0]\n      var result2 = $(template.parse({option: 3}))[0]\n\n      expect(result1).toEqual($(expected1)[0])\n      expect(result2).toEqual($(expected2)[0])\n    })\n  })\n\n  describe(':checked', function () {\n    it('should set `checked` attribute if the expression given is truthy', function () {\n      var source = '<input type=\"checkbox\" :checked=\"expression\">'\n      var expected1 = $('<input type=\"checkbox\" checked=\"checked\">')[0]\n      var expected2 = $('<input type=\"checkbox\">')[0]\n      var template = new Template(source)\n\n      var result1 = $(template.parse({expression: true}))[0]\n      var result2 = $(template.parse({expression: false}))[0]\n\n      expect(result1).toEqual(expected1)\n      expect(result2).toEqual(expected2)\n    })\n  })\n\n  describe(':href', function () {\n    it('should set `href` attribute to the expression given', function () {\n      var tpl = '<a :href=\"link\">My Link</a>'\n      var expected = '<a href=\"http://google.com\">My Link</a>'\n      var template = new Template(tpl)\n      var result = template.parse({link: 'http://google.com'})\n      expect(result).toEqual(expected)\n    })\n  })\n\n  describe(':src', function () {\n    it('should set `src` attribute to the expression given', function () {\n      var tpl = '<img :src=\"myImage\">'\n      var expected = '<img src=\"path/to/logo.svg\">'\n      var template = new Template(tpl)\n      var result = template.parse({myImage: 'path/to/logo.svg'})\n      expect($(result)[0]).toEqual($(expected)[0])\n    })\n  })\n\n  describe(':value', function () {\n    it('should set `value` attribute to the expression given', function () {\n      var tpl = '<input type=\"text\" :value=\"name\">'\n      var expected = '<input type=\"text\" value=\"Guilherme Santiago\">'\n      var template = new Template(tpl)\n      var result = template.parse({name: 'Guilherme Santiago'})\n      expect($(result)[0]).toEqual($(expected)[0])\n    })\n  })\n\n  describe(':title and :alt', function () {\n    it('should set `title` and `alt` attributes to the expression given to them', function () {\n      var tpl = '<img src=\"{{img.url}}\" :title=\"img.title\" :alt=\"img.description\">'\n      var expected = '<img src=\"foo/bar/image.png\" title=\"Image Title\" alt=\"Image Description\">'\n      var template = new Template(tpl)\n      var result = template.parse({img: {\n        url: 'foo/bar/image.png',\n        title: 'Image Title',\n        description: 'Image Description'\n      }})\n      expect($(result)[0]).toEqual($(expected)[0])\n    })\n  })\n\n  describe(':style', function () {\n    it('should set `style` attribute to the object given', function () {\n      var source = fs.readFileSync(__dirname + '/fixtures/templates/directive-style.html', 'utf8')\n      var expected1 = fs.readFileSync(__dirname + '/fixtures/templates/directive-style.expected1.html', 'utf8')\n      var expected2 = fs.readFileSync(__dirname + '/fixtures/templates/directive-style.expected2.html', 'utf8')\n      var template = new Template(source)\n\n      var result1 = $(template.parse({fontSize: 16}))[0]\n      var result2 = $(template.parse({fontSize: 14}))[0]\n\n      expect(result1).toEqual($(expected1)[0])\n      expect(result2).toEqual($(expected2)[0])\n    })\n  })\n\n  describe(':repeat', function () {\n    it('should iterate array', function () {\n      var source = fs.readFileSync(__dirname + '/fixtures/templates/iterate-array.html', 'utf8')\n      var expected = fs.readFileSync(__dirname + '/fixtures/templates/iterate-array.expected.html', 'utf8')\n      var template = new Template(source)\n      var result = template.parse({items: ['Banana', 'Orange', 'Apple', 'Pear']})\n\n      expect($(result)[0]).toEqual($(expected)[0])\n    })\n\n    it('should iterate object', function () {\n      var source = fs.readFileSync(__dirname + '/fixtures/templates/iterate-object.html', 'utf8')\n      var expected = fs.readFileSync(__dirname + '/fixtures/templates/iterate-object.expected.html', 'utf8')\n      var template = new Template(source)\n      var result = template.parse({users: {\n        Guilherme: 'guilherme@email.com',\n        Junin: 'junin@email.com',\n        Zillao: 'zillao@email.com'\n      }})\n\n      expect($(result)[0]).toEqual($(expected)[0])\n    })\n\n    it('should add special properties to each loop', function () {\n      var source = fs.readFileSync(__dirname + '/fixtures/templates/special-properties.html', 'utf8')\n      var expected = fs.readFileSync(__dirname + '/fixtures/templates/special-properties.expected.html', 'utf8')\n      var template = new Template(source)\n      var result = template.parse({\n        user: 'Initial user',\n        $index: 'Initial index',\n        $key: 'Initial key',\n        $total: 'Initial total',\n        $first: 'Initial first',\n        $middle: 'Initial middle',\n        $last: 'Initial last',\n        $even: 'Initial even',\n        $odd: 'Initial odd',\n        users: ['Guilherme', 'Junin', 'Zilla']\n      })\n\n      expect($(result)[0]).toEqual($(expected)[0])\n    })\n\n    it('should support nested :repeat', function () {\n      var source = fs.readFileSync(__dirname + '/fixtures/templates/nested-repeat.html', 'utf8')\n      var expected = fs.readFileSync(__dirname + '/fixtures/templates/nested-repeat.expected.html', 'utf8')\n      var template = new Template(source)\n      var result = template.parse({\n        users: [\n          {\n            name: 'Guilherme',\n            skills: ['html', 'css', 'js']\n          },\n          {\n            name: 'Zilla',\n            skills: ['php', 'mysql']\n          },\n          {\n            name: 'Junin',\n            skills: []\n          }\n        ]\n      })\n\n      expect(result).toEqual(expected)\n    })\n\n    it('should support other directives', function () {\n      var source = fs.readFileSync(__dirname + '/fixtures/templates/repeat-with-directives.html', 'utf8')\n      var expected = fs.readFileSync(__dirname + '/fixtures/templates/repeat-with-directives.expected.html', 'utf8')\n      var template = new Template(source)\n      var result = template.parse({\n        users: [\n          {\n            name: 'Guilherme',\n            email: 'guilherme@email.com'\n          },\n          {\n            name: 'Zilla'\n          },\n          {\n            name: 'Junin',\n            email: 'junin@email.com'\n          }\n        ]\n      })\n\n      expect($(result)[0]).toEqual($(expected)[0])\n    })\n\n    it('should not leak scope', function () {\n      var tpl = '<div :repeat=\"item in items\">{{ item }}</div>'\n      var vars = {items: ['a', 'b', 'c']}\n      var template = new Template(tpl)\n      template.parse($.extend({}, vars))\n      expect(template.vars).toEqual(vars)\n    })\n  })\n\n  it('should render `:repeat` first', function () {\n    var source = fs.readFileSync(__dirname + '/fixtures/templates/directive-priority.html', 'utf8')\n    var expected = fs.readFileSync(__dirname + '/fixtures/templates/directive-priority.expected.html', 'utf8')\n    var template = new Template(source)\n    var result = template.parse({items: ['First Item', 'Active Item', 'Last Item']})\n    expect(result).toEqual(expected)\n  })\n\n})","undoManager":{"mark":78,"position":100,"stack":[[{"start":{"row":486,"column":78},"end":{"row":486,"column":79},"action":"insert","lines":["e"],"id":14500}],[{"start":{"row":486,"column":79},"end":{"row":486,"column":80},"action":"insert","lines":["m"],"id":14501}],[{"start":{"row":486,"column":84},"end":{"row":487,"column":0},"action":"insert","lines":["",""],"id":14502},{"start":{"row":487,"column":0},"end":{"row":487,"column":4},"action":"insert","lines":["    "]}],[{"start":{"row":487,"column":4},"end":{"row":487,"column":5},"action":"insert","lines":["e"],"id":14503}],[{"start":{"row":487,"column":5},"end":{"row":487,"column":6},"action":"insert","lines":["x"],"id":14504}],[{"start":{"row":487,"column":6},"end":{"row":487,"column":7},"action":"insert","lines":["p"],"id":14505}],[{"start":{"row":487,"column":7},"end":{"row":487,"column":8},"action":"insert","lines":["e"],"id":14506}],[{"start":{"row":487,"column":8},"end":{"row":487,"column":9},"action":"insert","lines":["c"],"id":14507}],[{"start":{"row":487,"column":9},"end":{"row":487,"column":10},"action":"insert","lines":["t"],"id":14508}],[{"start":{"row":487,"column":10},"end":{"row":487,"column":12},"action":"insert","lines":["()"],"id":14509}],[{"start":{"row":487,"column":11},"end":{"row":487,"column":12},"action":"insert","lines":["$"],"id":14510}],[{"start":{"row":487,"column":12},"end":{"row":487,"column":14},"action":"insert","lines":["()"],"id":14511}],[{"start":{"row":487,"column":13},"end":{"row":487,"column":14},"action":"insert","lines":["r"],"id":14512}],[{"start":{"row":487,"column":14},"end":{"row":487,"column":15},"action":"insert","lines":["e"],"id":14513}],[{"start":{"row":487,"column":15},"end":{"row":487,"column":16},"action":"insert","lines":["s"],"id":14514}],[{"start":{"row":487,"column":16},"end":{"row":487,"column":17},"action":"insert","lines":["u"],"id":14515}],[{"start":{"row":487,"column":17},"end":{"row":487,"column":18},"action":"insert","lines":["l"],"id":14516}],[{"start":{"row":487,"column":18},"end":{"row":487,"column":19},"action":"insert","lines":["t"],"id":14517}],[{"start":{"row":487,"column":20},"end":{"row":487,"column":22},"action":"insert","lines":["[]"],"id":14518}],[{"start":{"row":487,"column":21},"end":{"row":487,"column":22},"action":"insert","lines":["0"],"id":14519}],[{"start":{"row":487,"column":24},"end":{"row":487,"column":25},"action":"insert","lines":["."],"id":14520}],[{"start":{"row":487,"column":25},"end":{"row":487,"column":26},"action":"insert","lines":["t"],"id":14521}],[{"start":{"row":487,"column":26},"end":{"row":487,"column":27},"action":"insert","lines":["o"],"id":14522}],[{"start":{"row":487,"column":27},"end":{"row":487,"column":28},"action":"insert","lines":["E"],"id":14523}],[{"start":{"row":487,"column":28},"end":{"row":487,"column":29},"action":"insert","lines":["q"],"id":14524}],[{"start":{"row":487,"column":29},"end":{"row":487,"column":30},"action":"insert","lines":["u"],"id":14525}],[{"start":{"row":487,"column":30},"end":{"row":487,"column":31},"action":"insert","lines":["a"],"id":14526}],[{"start":{"row":487,"column":31},"end":{"row":487,"column":32},"action":"insert","lines":["l"],"id":14527}],[{"start":{"row":487,"column":32},"end":{"row":487,"column":34},"action":"insert","lines":["()"],"id":14528}],[{"start":{"row":487,"column":33},"end":{"row":487,"column":34},"action":"insert","lines":["$"],"id":14529}],[{"start":{"row":487,"column":34},"end":{"row":487,"column":36},"action":"insert","lines":["()"],"id":14530}],[{"start":{"row":487,"column":35},"end":{"row":487,"column":36},"action":"insert","lines":["e"],"id":14531}],[{"start":{"row":487,"column":36},"end":{"row":487,"column":37},"action":"insert","lines":["x"],"id":14532}],[{"start":{"row":487,"column":37},"end":{"row":487,"column":38},"action":"insert","lines":["p"],"id":14533}],[{"start":{"row":487,"column":38},"end":{"row":487,"column":39},"action":"insert","lines":["e"],"id":14534}],[{"start":{"row":487,"column":39},"end":{"row":487,"column":40},"action":"insert","lines":["c"],"id":14535}],[{"start":{"row":487,"column":40},"end":{"row":487,"column":41},"action":"insert","lines":["t"],"id":14536}],[{"start":{"row":487,"column":41},"end":{"row":487,"column":42},"action":"insert","lines":["e"],"id":14537}],[{"start":{"row":487,"column":42},"end":{"row":487,"column":43},"action":"insert","lines":["d"],"id":14538}],[{"start":{"row":487,"column":44},"end":{"row":487,"column":46},"action":"insert","lines":["[]"],"id":14539}],[{"start":{"row":487,"column":45},"end":{"row":487,"column":46},"action":"insert","lines":["0"],"id":14540}],[{"start":{"row":487,"column":11},"end":{"row":487,"column":23},"action":"remove","lines":["$(result)[0]"],"id":14541},{"start":{"row":487,"column":11},"end":{"row":487,"column":12},"action":"insert","lines":["r"]}],[{"start":{"row":487,"column":12},"end":{"row":487,"column":13},"action":"insert","lines":["e"],"id":14542}],[{"start":{"row":487,"column":13},"end":{"row":487,"column":14},"action":"insert","lines":["s"],"id":14543}],[{"start":{"row":487,"column":14},"end":{"row":487,"column":15},"action":"insert","lines":["u"],"id":14544}],[{"start":{"row":487,"column":15},"end":{"row":487,"column":16},"action":"insert","lines":["l"],"id":14545}],[{"start":{"row":487,"column":16},"end":{"row":487,"column":17},"action":"insert","lines":["t"],"id":14546}],[{"start":{"row":487,"column":27},"end":{"row":487,"column":41},"action":"remove","lines":["$(expected)[0]"],"id":14547},{"start":{"row":487,"column":27},"end":{"row":487,"column":28},"action":"insert","lines":["e"]}],[{"start":{"row":487,"column":28},"end":{"row":487,"column":29},"action":"insert","lines":["x"],"id":14548}],[{"start":{"row":487,"column":29},"end":{"row":487,"column":30},"action":"insert","lines":["p"],"id":14549}],[{"start":{"row":487,"column":30},"end":{"row":487,"column":31},"action":"insert","lines":["e"],"id":14550}],[{"start":{"row":487,"column":31},"end":{"row":487,"column":32},"action":"insert","lines":["c"],"id":14551}],[{"start":{"row":487,"column":32},"end":{"row":487,"column":33},"action":"insert","lines":["t"],"id":14552}],[{"start":{"row":487,"column":33},"end":{"row":487,"column":34},"action":"insert","lines":["e"],"id":14553}],[{"start":{"row":487,"column":34},"end":{"row":487,"column":35},"action":"insert","lines":["d"],"id":14554}],[{"start":{"row":482,"column":20},"end":{"row":482,"column":42},"action":"remove","lines":["according to its order"],"id":14555}],[{"start":{"row":482,"column":20},"end":{"row":482,"column":21},"action":"insert","lines":["{"],"id":14556}],[{"start":{"row":482,"column":21},"end":{"row":482,"column":22},"action":"insert","lines":[" "],"id":14557}],[{"start":{"row":482,"column":22},"end":{"row":482,"column":23},"action":"insert","lines":[":"],"id":14558}],[{"start":{"row":482,"column":22},"end":{"row":482,"column":23},"action":"remove","lines":[":"],"id":14559}],[{"start":{"row":482,"column":21},"end":{"row":482,"column":22},"action":"remove","lines":[" "],"id":14560}],[{"start":{"row":482,"column":20},"end":{"row":482,"column":21},"action":"remove","lines":["{"],"id":14561}],[{"start":{"row":482,"column":20},"end":{"row":482,"column":21},"action":"insert","lines":["`"],"id":14562}],[{"start":{"row":482,"column":21},"end":{"row":482,"column":22},"action":"insert","lines":[":"],"id":14563}],[{"start":{"row":482,"column":22},"end":{"row":482,"column":23},"action":"insert","lines":["r"],"id":14564}],[{"start":{"row":482,"column":23},"end":{"row":482,"column":24},"action":"insert","lines":["e"],"id":14565}],[{"start":{"row":482,"column":24},"end":{"row":482,"column":25},"action":"insert","lines":["p"],"id":14566}],[{"start":{"row":482,"column":25},"end":{"row":482,"column":26},"action":"insert","lines":["e"],"id":14567}],[{"start":{"row":482,"column":26},"end":{"row":482,"column":27},"action":"insert","lines":["a"],"id":14568}],[{"start":{"row":482,"column":27},"end":{"row":482,"column":28},"action":"insert","lines":["t"],"id":14569}],[{"start":{"row":482,"column":28},"end":{"row":482,"column":29},"action":"insert","lines":["`"],"id":14570}],[{"start":{"row":482,"column":29},"end":{"row":482,"column":30},"action":"insert","lines":[" "],"id":14571}],[{"start":{"row":482,"column":30},"end":{"row":482,"column":31},"action":"insert","lines":["f"],"id":14572}],[{"start":{"row":482,"column":31},"end":{"row":482,"column":32},"action":"insert","lines":["i"],"id":14573}],[{"start":{"row":482,"column":32},"end":{"row":482,"column":33},"action":"insert","lines":["r"],"id":14574}],[{"start":{"row":482,"column":33},"end":{"row":482,"column":34},"action":"insert","lines":["s"],"id":14575}],[{"start":{"row":482,"column":34},"end":{"row":482,"column":35},"action":"insert","lines":["t"],"id":14576}],[{"start":{"row":482,"column":0},"end":{"row":490,"column":0},"action":"remove","lines":["  it('should render `:repeat` first', function () {","    var source = fs.readFileSync(__dirname + '/fixtures/templates/directive-priority.html', 'utf8')","    var expected = fs.readFileSync(__dirname + '/fixtures/templates/directive-priority.expected.html', 'utf8')","    var template = new Template(source)","    var result = template.parse({items: ['First Item', 'Active Item', 'Last Item']})","    expect(result).toEqual(expected)","  })","",""],"id":14577,"ignore":true},{"start":{"row":482,"column":2},"end":{"row":483,"column":0},"action":"insert","lines":["",""]}],[{"start":{"row":482,"column":0},"end":{"row":490,"column":0},"action":"insert","lines":["  it('should render `:repeat` first', function () {","    var source = fs.readFileSync(__dirname + '/fixtures/templates/directive-priority.html', 'utf8')","    var expected = fs.readFileSync(__dirname + '/fixtures/templates/directive-priority.expected.html', 'utf8')","    var template = new Template(source)","    var result = template.parse({items: ['First Item', 'Active Item', 'Last Item']})","    expect(result).toEqual(expected)","  })","",""],"id":14578,"ignore":true},{"start":{"row":490,"column":2},"end":{"row":491,"column":0},"action":"remove","lines":["",""]}],[{"start":{"row":52,"column":7},"end":{"row":52,"column":8},"action":"insert","lines":["f"],"id":14579}],[{"start":{"row":52,"column":8},"end":{"row":52,"column":9},"action":"insert","lines":["o"],"id":14580}],[{"start":{"row":52,"column":9},"end":{"row":52,"column":10},"action":"insert","lines":["d"],"id":14581}],[{"start":{"row":52,"column":10},"end":{"row":52,"column":11},"action":"insert","lines":["a"],"id":14582}],[{"start":{"row":52,"column":11},"end":{"row":52,"column":12},"action":"insert","lines":["-"],"id":14583}],[{"start":{"row":52,"column":11},"end":{"row":52,"column":12},"action":"remove","lines":["-"],"id":14584}],[{"start":{"row":52,"column":10},"end":{"row":52,"column":11},"action":"remove","lines":["a"],"id":14585}],[{"start":{"row":52,"column":9},"end":{"row":52,"column":10},"action":"remove","lines":["d"],"id":14586}],[{"start":{"row":52,"column":8},"end":{"row":52,"column":9},"action":"remove","lines":["o"],"id":14587}],[{"start":{"row":52,"column":7},"end":{"row":52,"column":8},"action":"remove","lines":["f"],"id":14588}],[{"start":{"row":127,"column":6},"end":{"row":127,"column":7},"action":"insert","lines":["n"],"id":14589}],[{"start":{"row":127,"column":7},"end":{"row":127,"column":8},"action":"insert","lines":["a"],"id":14590}],[{"start":{"row":127,"column":8},"end":{"row":127,"column":9},"action":"insert","lines":[" "],"id":14591}],[{"start":{"row":127,"column":9},"end":{"row":127,"column":10},"action":"insert","lines":["r"],"id":14592}],[{"start":{"row":127,"column":10},"end":{"row":127,"column":11},"action":"insert","lines":["e"],"id":14593}],[{"start":{"row":127,"column":11},"end":{"row":127,"column":12},"action":"insert","lines":["a"],"id":14594}],[{"start":{"row":127,"column":11},"end":{"row":127,"column":12},"action":"remove","lines":["a"],"id":14595}],[{"start":{"row":127,"column":10},"end":{"row":127,"column":11},"action":"remove","lines":["e"],"id":14596}],[{"start":{"row":127,"column":9},"end":{"row":127,"column":10},"action":"remove","lines":["r"],"id":14597}],[{"start":{"row":127,"column":8},"end":{"row":127,"column":9},"action":"remove","lines":[" "],"id":14598}],[{"start":{"row":127,"column":7},"end":{"row":127,"column":8},"action":"remove","lines":["a"],"id":14599}],[{"start":{"row":127,"column":6},"end":{"row":127,"column":7},"action":"remove","lines":["n"],"id":14600}]]},"ace":{"folds":[],"scrolltop":6001,"scrollleft":0,"selection":{"start":{"row":239,"column":39},"end":{"row":239,"column":39},"isBackwards":false},"options":{"guessTabSize":true,"useWrapMode":false,"wrapToView":true},"firstLineState":{"row":249,"state":"start","mode":"ace/mode/javascript"}},"timestamp":1461775047000}